;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "hl-todo" "20251101.2019"
  "Highlight TODO and similar keywords."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/hl-todo"
  :commit "94893087e0aca6642a3ebf11f46b3d5f47c1eb22"
  :revdesc "94893087e0ac"
  :keywords '("convenience")
  :authors '(("Jonas Bernoulli" . "emacs.hl-todo@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.hl-todo@jonas.bernoulli.dev")))
